%% Correlation of CB01 with NorthGRIP for YD, Heinrich Events and D/O Cycles
% by M.H. Trauth 6 Nov 2017

%%
% Clear workspace, command window and close all figures. Load CB01 and
% NorthGRIP data from files. Remove rows with NaNs.
clear, clc, close all
CB01xrf_ages = load('CB_PC1_ages.txt');
CB01xrf_ages(isnan(CB01xrf_ages(:,1))==1,:) = [];
NGripd18O = load('ngrip-d18o-50yr.txt');

%% 
% Remote duplicate data points.
for i = 1:size(NGripd18O,1)-1
    if NGripd18O(i,1) == NGripd18O(i+1,1)
       NGripd18O(i,1) = NaN;
    end
end
NGripd18O(isnan(NGripd18O(:,1))==1,:) = [];

%% 
% Calculate avarage time spacing between subsequent data point. Define
% evenly spaced time vector and interpolate data.
min(CB01xrf_ages(:,1))
max(CB01xrf_ages(:,1))
mean(diff(CB01xrf_ages(:,1)))
t =  1000 : 15 : 45350; t = t';
cb01 = interp1(CB01xrf_ages(:,1),CB01xrf_ages(:,2),t,'linear','extrap');
ngrip = interp1(NGripd18O(:,1),NGripd18O(:,2),t,'linear','extrap');

%% 
% Heinrich Events (Hemming, 2014; Bond and Lotti, 1995; Vidal et al. 1999,
% dates from Wikipedia)
he_hemming = 1000*[12 16.8 24 31 38 45 60]';
he_labels = ['H0';'H1';'H2';'H3';'H4';'H5';'H6'];
he_bondlotti = 1000*[23 29 37]';
he_vidal = 1000*[14 22 35 45]';

%% 
% Cross Correlation of the full record.
r = corr(cb01,ngrip,'Type','Pearson','Rows','Pairwise')
r = corr(cb01,ngrip,'Type','Spearman','Rows','Pairwise')
r = corr(cb01,ngrip,'Type','Kendall','Rows','Pairwise')

%% 
% Calculate piecewise cross correlation within window of size w. Very
% important: High negative correlation means low NorthGRIP temperatures
% correspond to high potassium values (= dry climate). The window size of n
% corresponds to |n| times |15| years which is the resolution of the |t|
% vector.
w = 100; 
for i = w/2+1:length(cb01)-w/2
    [p,h] = corr(cb01(i-w/2:i+w/2),ngrip(i-w/2:i+w/2),'Type','Spearman');
    corrt(1,i) = p;
end
corrt(1,1:w/2) = corrt(1,w/2+1) * ones(1,w/2); 
corrt(1,length(cb01)-w/2+1:length(cb01)) = ...
    corrt(1,length(cb01)-w/2) * ones(1,w/2);
corrt = corrt';

%% 
% Display the data. Very important: High negative correlation means low
% NorthGRIP temperatures correspond to high CB01 potassium values (= dry
% climate). The |corrt| graphic is therefore displayed on a reverse y-axis.
fig = figure('Color',[1 1 1],...
    'Position',[50 1000 1200 600]);
axes('Units','Centimeters',...
    'Position',[5.5 15 32.8 6],...
    'XLim',[0 50],...
    'YLim',[-6 5],...
    'Box','On',...
    'YDir','Reverse',...
    'XGrid','On',...
    'YGrid','On',...
    'XTick',[],...
    'LineWidth',1,...
    'FontSize',14);
line(t/1000,cb01,'Color',[0.8510 0.3255 0.0980],'LineWidth',1)
text(48.000,-2.5,'A','FontSize',24)
ylabel('K (PC1 Scores)')
axes('Units','Centimeters',...
    'Position',[5.5 8.5 32.8 6],...
    'XLim',[0 50],...
    'Box','On',...
    'XGrid','On',...
    'YGrid','On',...
    'XTick',[],...
    'LineWidth',1,...
    'FontSize',14); 
line(t/1000,ngrip,'LineWidth',1), hold on
stem(he_hemming/1000,-30*ones(size(he_hemming)),...
    'BaseValue',-50,...
    'Color',[0.4667 0.6745 0.1882],...
    'Marker','none',...
    'LineWidth',1)
text((he_hemming+500)/1000,-35*ones(size(he_hemming)),he_labels,...
    'FontSize',14)
text(48.000,-35,'B','FontSize',24)
ylabel('{ \delta}^{18}O (Permille vs. PDB)')
axes('Units','Centimeters',...
    'Position',[5.5 2 32.8 6],...
    'XLim',[0 50],...
    'Box','On',...
    'XGrid','On',...
    'YGrid','On',...
    'YDir','Reverse',...
    'LineWidth',1,...
    'FontSize',14);
line(t/1000,corrt,'LineWidth',1), hold on
nt = t; ncorrt = corrt;
nt(corrt>0)=NaN; ncorrt(corrt>0)=NaN;
line(nt/1000,ncorrt,'Color',[0.8510 0.3255 0.0980],...
    'LineWidth',1)
line([0 50.000],[0 0],...
    'Color',[0.8510 0.3255 0.0980],...
    'LineWidth',1)
text(48.000,-0.75,'C',...
    'FontSize',24)
xlabel('Age (ka)')
ylabel('Corr Coef')

orient(fig,'landscape')
print(fig,'trauth_figure_6.pdf','-dpdf','-bestfit')

